==> kdesdk-4.6.1.tar.bz2: kdesdk-4.6.1/okteta/kasten/controllers/view/viewprofiles/viewprofilesmanagedialog.h <==
/*
    This file is part of the Okteta Kasten module, part of the KDE project.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef VIEWPROFILESMANAGEDIALOG_H
#define VIEWPROFILESMANAGEDIALOG_H

// Okteta Gui Kasten
#include <bytearrayviewprofile.h>
// KDE
#include <KDialog>
// Qt
#include <QtCore/QList>

class QTreeView;

namespace Kasten
{

class ViewProfileTableModel;


class ViewProfilesManageDialog : public KDialog
{
  Q_OBJECT

  public:
    explicit ViewProfilesManageDialog( QWidget* parent = 0 );

    virtual ~ViewProfilesManageDialog();

  public:
    void setViewProfiles( const QList<ByteArrayViewProfile>& viewProfiles );

  protected Q_SLOTS:
    void onCreateNewButtonClicked();
    void onEditButtonClicked();
    void onSetDefaultButtonClicked();
    void onDeleteButtonClicked();

  private:
    QList<ByteArrayViewProfile> mViewProfiles;

    ViewProfileTableModel* mViewProfileTableModel;

    QTreeView* mViewProfileTableView;
};

}

#endif

==> kdesdk-4.7.0.tar.bz2: kdesdk-4.7.0/okteta/kasten/controllers/view/viewprofiles/viewprofilesmanagedialog.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef VIEWPROFILESMANAGEDIALOG_H
#define VIEWPROFILESMANAGEDIALOG_H

// Okteta Gui Kasten
#include <bytearrayviewprofile.h>
// KDE
#include <KDialog>
// Qt
#include <QtCore/QList>

class QTreeView;

namespace Kasten
{

class ViewProfileTableModel;


class ViewProfilesManageDialog : public KDialog
{
  Q_OBJECT

  public:
    explicit ViewProfilesManageDialog( QWidget* parent = 0 );

    virtual ~ViewProfilesManageDialog();

  public:
    void setViewProfiles( const QList<ByteArrayViewProfile>& viewProfiles );

  protected Q_SLOTS:
    void onCreateNewButtonClicked();
    void onEditButtonClicked();
    void onSetDefaultButtonClicked();
    void onDeleteButtonClicked();

  private:
    QList<ByteArrayViewProfile> mViewProfiles;

    ViewProfileTableModel* mViewProfileTableModel;

    QTreeView* mViewProfileTableView;
};

}

#endif
